Improve this Doc View Source

Determines if a reference is a `Number`.

This includes the "special" numbers `NaN`, `+Infinity` and `-Infinity`.

If you wish to exclude these then you can use the native `isFinite' method.

## Usage

`angular.isNumber(value);`

### Arguments

Param | Type | Details
--- | --- | ---
value | * | Reference to check.

### Returns

boolean | True if `value` is a `Number`.